@@ -55,7 +55,7 @@ CREATE OR REPLACE FUNCTION standardize_address(
         micro text,
         macro text )
     RETURNS stdaddr
-    AS  '$libdir/address_standardizer-2.4', 'standardize_address'
+    AS  '$libdir/address_standardizer', 'standardize_address'
     LANGUAGE 'c' IMMUTABLE STRICT COST 200;
 
 CREATE OR REPLACE FUNCTION standardize_address(
@@ -64,7 +64,7 @@ CREATE OR REPLACE FUNCTION standardize_address(
         rultab text,
         address text )
     RETURNS stdaddr
-    AS  '$libdir/address_standardizer-2.4', 'standardize_address1'
+    AS  '$libdir/address_standardizer', 'standardize_address1'
     LANGUAGE 'c' IMMUTABLE STRICT COST 200;
 
 CREATE OR REPLACE FUNCTION parse_address(IN text,
@@ -78,6 +78,6 @@ CREATE OR REPLACE FUNCTION parse_address(IN text,
         OUT zipplus text,
         OUT country text)
     RETURNS record
-    AS  '$libdir/address_standardizer-2.4', 'parse_address'
+    AS  '$libdir/address_standardizer', 'parse_address'
     LANGUAGE 'c' IMMUTABLE STRICT;
 
